@@ -33,9 +33,6 @@ G_BEGIN_DECLS
 GtkBuilder     *xfpm_builder_new_from_string   	(const gchar *file,
 						 GError **error);
 
-GdkPixbuf* 	xfpm_load_icon    		(const gchar *icon_name,
-						 gint size) G_GNUC_MALLOC;
-
 void       	xfpm_lock_screen  		(void);
 
 void       	xfpm_preferences		(void);
@@ -47,6 +44,8 @@ void            xfpm_quit                       (void);
 void       	xfpm_about			(GtkWidget *widget, 
 						 gpointer data);
 
+gboolean	xfpm_is_multihead_connected	(void);
+
 G_END_DECLS
 
 #endif /* XFPM_COMMON_H */
