@@ -31,6 +31,7 @@
 #include <libxfcegui4/libxfcegui4.h>
 
 #include "libxfpm/xfpm-common.h"
+#include "libxfpm/xfpm-icons.h"
 
 #include "brightness-button.h"
 #include "brightness-proxy.h"
@@ -557,7 +558,7 @@ brightness_button_set_icon (BrightnessButton *button, gint width)
     
     hw_found = brightness_proxy_has_hw (button->priv->brightness);
     
-    icon_name = hw_found ? "xfpm-brightness-lcd" : "xfpm-brightness-lcd-invalid";
+    icon_name = hw_found ? XFPM_DISPLAY_BRIGHTNESS_ICON : XFPM_DISPLAY_BRIGHTNESS_INVALID_ICON;
     
     pixbuf = xfce_themed_icon_load (icon_name, width);
     
