@@ -990,8 +990,10 @@ xfpm_settings_on_ac (XfconfChannel *channel, gboolean user_privilege, gboolean c
     }
     else
     {
-	frame = GTK_WIDGET (gtk_builder_get_object (xml, "on-ac-actions-frame"));
-	gtk_widget_hide_all (frame);
+	GtkWidget *label;
+	label = GTK_WIDGET (gtk_builder_get_object (xml, "on-ac-lid-label"));
+	gtk_widget_hide (label);
+	gtk_widget_hide (lid);
     }
     
     /*
