@@ -33,18 +33,16 @@ typedef enum
 {
     XFPM_ERROR_UNKNOWN = 0,
     XFPM_ERROR_PERMISSION_DENIED,
-    XFPM_ERROR_SUSPEND_NOT_SUPPORTED,
-    XFPM_ERROR_HIBERNATE_NOT_SUPPORTED,
-    XFPM_ERROR_SUSPEND_HYBRID_NOT_SUPPORTED,
-    XFPM_ERROR_INVALID_COOKIE,
+    XFPM_ERROR_NO_HARDWARE_SUPPORT,
+    XFPM_ERROR_COOKIE_NOT_FOUND,
     XFPM_ERROR_INVALID_ARGUMENTS,
     XFPM_ERROR_HAL_DISCONNECTED,
     XFPM_ERROR_SLEEP_FAILED
     
 } XfpmError;
 
-GType	xfpm_error_get_type  () G_GNUC_CONST;
-GQuark  xfpm_get_error_quark ();
+GType	xfpm_error_get_type  (void) G_GNUC_CONST;
+GQuark  xfpm_get_error_quark (void);
 
 
 G_END_DECLS
