@@ -305,9 +305,6 @@ static void xfpm_inhibit_dbus_class_init  (XfpmInhibitClass *klass)
     dbus_g_object_type_install_info(G_TYPE_FROM_CLASS(klass),
 				    &dbus_glib_xfpm_inhibit_object_info);
 				    
-    dbus_g_error_domain_register (XFPM_ERROR, 
-				  "org.freedesktop.PowerManagement.Inhibit",
-				  XFPM_TYPE_ERROR);
 }
 
 static void xfpm_inhibit_dbus_init	  (XfpmInhibit *inhibit)
@@ -356,7 +353,7 @@ static gboolean xfpm_inhibit_un_inhibit    (XfpmInhibit *inhibit,
     
     if (!xfpm_inhibit_remove_application_by_cookie (inhibit, IN_cookie))
     {
-	g_set_error (error, XFPM_ERROR, XFPM_ERROR_INVALID_COOKIE, _("Invalid cookie"));
+	g_set_error (error, XFPM_ERROR, XFPM_ERROR_COOKIE_NOT_FOUND, _("Invalid cookie"));
 	return FALSE;
     }
     
