@@ -45,6 +45,7 @@
 #include "xfpm-engine.h"
 #include "xfpm-session.h"
 #include "xfpm-dbus-monitor.h"
+#include "xfpm-errors.h"
 
 static void xfpm_manager_finalize   (GObject *object);
 
@@ -100,6 +101,7 @@ xfpm_manager_system_bus_connection_changed_cb (XfpmDBusMonitor *monitor, gboolea
 static void
 xfpm_manager_session_die_cb (XfpmSession *session, XfpmManager *manager)
 {
+    TRACE ("Session die signal, exiting");
     xfpm_manager_quit (manager);
 }
 
@@ -168,8 +170,10 @@ xfpm_manager_release_names (XfpmManager *manager)
 static gboolean
 xfpm_manager_quit (XfpmManager *manager)
 {
+    TRACE ("Exiting");
+    
     xfpm_manager_release_names (manager);
-    //xfpm_session_quit (manager->priv->session);
+    xfpm_session_quit (manager->priv->session);
     
     g_object_unref (G_OBJECT (manager));
     
@@ -177,21 +181,21 @@ xfpm_manager_quit (XfpmManager *manager)
     return TRUE;
 }
 
-static void
+static gboolean
 xfpm_manager_reserve_names (XfpmManager *manager)
 {
-    if ( !xfpm_dbus_register_name (dbus_g_connection_get_connection(manager->priv->session_bus),
-				  "org.xfce.PowerManager") ) 
-    {
-	g_critical("Unable to reserve bus name: Xfce Power Manager\n");
-    }
-    
-    if (!xfpm_dbus_register_name (dbus_g_connection_get_connection(manager->priv->session_bus),
+    if ( !xfpm_dbus_register_name (dbus_g_connection_get_connection (manager->priv->session_bus),
+				   "org.xfce.PowerManager") ||
+	 !xfpm_dbus_register_name (dbus_g_connection_get_connection (manager->priv->session_bus),
 				  "org.freedesktop.PowerManagement") )
     {
-    
-	g_critical ("Unable to reserve bus name: PowerManagement\n");
+	g_warning ("Unable to reserve bus name: Maybe any already running instance?\n");
+	xfpm_session_quit (manager->priv->session);
+	g_object_unref (G_OBJECT (manager));
+	gtk_main_quit ();
+	return FALSE;
     }
+    return TRUE;
 }
 
 XfpmManager *
@@ -212,7 +216,12 @@ void xfpm_manager_start (XfpmManager *manager)
 {
     gboolean hal_running;
     
-    xfpm_manager_reserve_names (manager);
+    if ( !xfpm_manager_reserve_names (manager) )
+	goto out;
+	
+    dbus_g_error_domain_register (XFPM_ERROR,
+				  NULL,
+				  XFPM_TYPE_ERROR);
     
     hal_running = xfpm_dbus_monitor_hal_connected (manager->priv->monitor);
     
@@ -229,7 +238,7 @@ out:
 
 void xfpm_manager_stop (XfpmManager *manager)
 {
-    
+    TRACE ("Stopping");
     g_return_if_fail (XFPM_IS_MANAGER (manager));
     xfpm_manager_quit (manager);
 }
